/*
**	Spy User Capture Interface (UCI) example driver
**
**	$Id: uci_example.c,v 1.1 1999/01/17 22:19:07 gromeck Exp $
**
**	$Log: uci_example.c,v $
**	Revision 1.1  1999/01/17 22:19:07  gromeck
**	initial version
**	
*/
#include <stdio.h>
#include <unistd.h>
#include <signal.h>

#define UCI_MIN_DATA_LEN	1
#define UCI_MAX_DATA_LEN	8092

static int _abort = 0;

static void abort_handler(int sig)
{
	_abort = 1;
	fprintf(stderr,"received signal %d\n",sig);
}

main(int argc,char *argv[])
{
	int n,c;
	char data[UCI_MAX_DATA_LEN];
	int delay = 1000;

	/*
	**	check the arguments
	*/
	while ((c = getopt(argc,argv,"vd:")) != EOF) {
		/*
		**	parse options
		*/
		switch (c) {
			case 'v':	fprintf(stderr,"*** User Capture Interface (UCI) example driver ***\n");
						fprintf(stderr,"$ID$\n");
						exit(0);
			case 'd':	delay = atol(optarg);
						break;
			case '?':	
			case ':':	
						goto usage;
						break;
			default:
			usage:		fprintf(stderr,"usage: %s [-v]\n",argv[0]);
						fprintf(stderr,"options: -v     print version and exit\n");
						fprintf(stderr,"         -d n   where n is the delay in milli seconds\n");
						exit(-1);
		}
	}
	for (n = optind;n < argc;n++) { 
		/*
		**	parse other arguments
		*/
		goto usage;
	}
	
	/*
	**	set the abort handler
	*/
	signal(SIGINT,abort_handler);

	/*
	**	open the input channel
	**	(prepare hardware, open interface, ...)
	*/

	/*
	**	copy the data to stdout
	*/
	for (_abort = 0;!_abort;) {
		int len = 100;

		if (write(1,&len,sizeof(len)) < 0)
			break;
		if (write(1,data,len) < 0)
			break;
		if (delay)
			usleep(delay * 1000);
	}

	/*
	**	close the input channel
	**	(leave hardware in a good state, close interface, ...)
	*/

	fprintf(stderr,"%s: terminating\n",argv[0]);
	exit(0);
}/**/
